@@ -2,15 +2,18 @@ from .structs import Pair
 
 AAVE_CRO = Pair("AAVE_CRO", price_precision=2, quantity_precision=3)
 AAVE_USDT = Pair("AAVE_USDT", price_precision=3, quantity_precision=4)
-ADA_BTC = Pair("ADA_BTC", price_precision=8, quantity_precision=0)
+ADA_BTC = Pair("ADA_BTC", price_precision=9, quantity_precision=0)
 ADA_CRO = Pair("ADA_CRO", price_precision=3, quantity_precision=2)
 ADA_USDT = Pair("ADA_USDT", price_precision=5, quantity_precision=1)
 ALGO_BTC = Pair("ALGO_BTC", price_precision=8, quantity_precision=2)
 ALGO_CRO = Pair("ALGO_CRO", price_precision=3, quantity_precision=2)
 ALGO_USDT = Pair("ALGO_USDT", price_precision=4, quantity_precision=2)
+ANKR_USDT = Pair("ANKR_USDT", price_precision=6, quantity_precision=1)
 ATOM_BTC = Pair("ATOM_BTC", price_precision=7, quantity_precision=2)
 ATOM_CRO = Pair("ATOM_CRO", price_precision=2, quantity_precision=2)
 ATOM_USDT = Pair("ATOM_USDT", price_precision=3, quantity_precision=2)
+BAL_CRO = Pair("BAL_CRO", price_precision=2, quantity_precision=3)
+BAL_USDT = Pair("BAL_USDT", price_precision=3, quantity_precision=3)
 BAND_CRO = Pair("BAND_CRO", price_precision=3, quantity_precision=2)
 BAND_USDT = Pair("BAND_USDT", price_precision=4, quantity_precision=2)
 BAT_CRO = Pair("BAT_CRO", price_precision=3, quantity_precision=2)
@@ -22,36 +25,43 @@ BNT_CRO = Pair("BNT_CRO", price_precision=3, quantity_precision=2)
 BNT_USDT = Pair("BNT_USDT", price_precision=4, quantity_precision=3)
 BTC_USDC = Pair("BTC_USDC", price_precision=2, quantity_precision=6)
 BTC_USDT = Pair("BTC_USDT", price_precision=2, quantity_precision=6)
-CELR_CRO = Pair("CELR_CRO", price_precision=4, quantity_precision=1)
-CELR_USDT = Pair("CELR_USDT", price_precision=5, quantity_precision=1)
+CELR_CRO = Pair("CELR_CRO", price_precision=5, quantity_precision=1)
+CELR_USDT = Pair("CELR_USDT", price_precision=6, quantity_precision=1)
+CHZ_USDT = Pair("CHZ_USDT", price_precision=5, quantity_precision=2)
 COMP_CRO = Pair("COMP_CRO", price_precision=2, quantity_precision=3)
 COMP_USDT = Pair("COMP_USDT", price_precision=2, quantity_precision=5)
-CRO_BTC = Pair("CRO_BTC", price_precision=8, quantity_precision=2)
-CRO_USDC = Pair("CRO_USDC", price_precision=4, quantity_precision=3)
-CRO_USDT = Pair("CRO_USDT", price_precision=4, quantity_precision=3)
+CRO_BTC = Pair("CRO_BTC", price_precision=9, quantity_precision=2)
+CRO_USDC = Pair("CRO_USDC", price_precision=5, quantity_precision=3)
+CRO_USDT = Pair("CRO_USDT", price_precision=5, quantity_precision=3)
 CRV_CRO = Pair("CRV_CRO", price_precision=3, quantity_precision=2)
 CRV_USDT = Pair("CRV_USDT", price_precision=4, quantity_precision=4)
 DAI_CRO = Pair("DAI_CRO", price_precision=3, quantity_precision=3)
 DAI_USDT = Pair("DAI_USDT", price_precision=4, quantity_precision=3)
+DOGE_BTC = Pair("DOGE_BTC", price_precision=10, quantity_precision=1)
+DOGE_CRO = Pair("DOGE_CRO", price_precision=4, quantity_precision=2)
+DOGE_USDT = Pair("DOGE_USDT", price_precision=5, quantity_precision=2)
+DOT_BTC = Pair("DOT_BTC", price_precision=7, quantity_precision=4)
 DOT_CRO = Pair("DOT_CRO", price_precision=3, quantity_precision=3)
 DOT_USDT = Pair("DOT_USDT", price_precision=4, quantity_precision=3)
 EGLD_CRO = Pair("EGLD_CRO", price_precision=3, quantity_precision=2)
 EGLD_USDT = Pair("EGLD_USDT", price_precision=4, quantity_precision=3)
+ENJ_BTC = Pair("ENJ_BTC", price_precision=9, quantity_precision=2)
 ENJ_CRO = Pair("ENJ_CRO", price_precision=3, quantity_precision=2)
 ENJ_USDT = Pair("ENJ_USDT", price_precision=5, quantity_precision=1)
-EOS_BTC = Pair("EOS_BTC", price_precision=7, quantity_precision=2)
+EOS_BTC = Pair("EOS_BTC", price_precision=8, quantity_precision=2)
 EOS_CRO = Pair("EOS_CRO", price_precision=3, quantity_precision=2)
 EOS_USDT = Pair("EOS_USDT", price_precision=4, quantity_precision=2)
-ETH_BTC = Pair("ETH_BTC", price_precision=6, quantity_precision=3)
-ETH_CRO = Pair("ETH_CRO", price_precision=2, quantity_precision=3)
+ETH_BTC = Pair("ETH_BTC", price_precision=6, quantity_precision=5)
+ETH_CRO = Pair("ETH_CRO", price_precision=2, quantity_precision=5)
 ETH_USDT = Pair("ETH_USDT", price_precision=2, quantity_precision=5)
+FIL_USDT = Pair("FIL_USDT", price_precision=3, quantity_precision=3)
 GRT_CRO = Pair("GRT_CRO", price_precision=3, quantity_precision=2)
 GRT_USDT = Pair("GRT_USDT", price_precision=5, quantity_precision=2)
 ICX_BTC = Pair("ICX_BTC", price_precision=8, quantity_precision=1)
-ICX_CRO = Pair("ICX_CRO", price_precision=2, quantity_precision=0)
+ICX_CRO = Pair("ICX_CRO", price_precision=3, quantity_precision=0)
 ICX_USDT = Pair("ICX_USDT", price_precision=4, quantity_precision=2)
 KNC_CRO = Pair("KNC_CRO", price_precision=3, quantity_precision=2)
-KNC_USDT = Pair("KNC_USDT", price_precision=3, quantity_precision=3)
+KNC_USDT = Pair("KNC_USDT", price_precision=4, quantity_precision=3)
 KSM_CRO = Pair("KSM_CRO", price_precision=2, quantity_precision=3)
 KSM_USDT = Pair("KSM_USDT", price_precision=3, quantity_precision=3)
 LINK_BTC = Pair("LINK_BTC", price_precision=7, quantity_precision=2)
@@ -59,20 +69,22 @@ LINK_CRO = Pair("LINK_CRO", price_precision=2, quantity_precision=2)
 LINK_USDT = Pair("LINK_USDT", price_precision=3, quantity_precision=2)
 LRC_CRO = Pair("LRC_CRO", price_precision=4, quantity_precision=2)
 LRC_USDT = Pair("LRC_USDT", price_precision=5, quantity_precision=2)
-LTC_BTC = Pair("LTC_BTC", price_precision=6, quantity_precision=2)
-LTC_CRO = Pair("LTC_CRO", price_precision=2, quantity_precision=2)
+LTC_BTC = Pair("LTC_BTC", price_precision=6, quantity_precision=4)
+LTC_CRO = Pair("LTC_CRO", price_precision=2, quantity_precision=4)
 LTC_USDT = Pair("LTC_USDT", price_precision=2, quantity_precision=5)
-MANA_BTC = Pair("MANA_BTC", price_precision=8, quantity_precision=1)
+MANA_BTC = Pair("MANA_BTC", price_precision=9, quantity_precision=1)
 MANA_CRO = Pair("MANA_CRO", price_precision=3, quantity_precision=2)
-MANA_USDT = Pair("MANA_USDT", price_precision=4, quantity_precision=2)
+MANA_USDT = Pair("MANA_USDT", price_precision=5, quantity_precision=2)
+MATIC_USDT = Pair("MATIC_USDT", price_precision=5, quantity_precision=2)
 MKR_CRO = Pair("MKR_CRO", price_precision=2, quantity_precision=3)
 MKR_USDT = Pair("MKR_USDT", price_precision=2, quantity_precision=6)
 NEAR_CRO = Pair("NEAR_CRO", price_precision=3, quantity_precision=2)
 NEAR_USDT = Pair("NEAR_USDT", price_precision=4, quantity_precision=2)
-NEO_BTC = Pair("NEO_BTC", price_precision=6, quantity_precision=3)
+NEO_BTC = Pair("NEO_BTC", price_precision=7, quantity_precision=3)
 NEO_CRO = Pair("NEO_CRO", price_precision=3, quantity_precision=2)
 NEO_USDT = Pair("NEO_USDT", price_precision=3, quantity_precision=4)
-OMG_BTC = Pair("OMG_BTC", price_precision=6, quantity_precision=4)
+OCEAN_USDT = Pair("OCEAN_USDT", price_precision=4, quantity_precision=2)
+OMG_BTC = Pair("OMG_BTC", price_precision=8, quantity_precision=4)
 OMG_CRO = Pair("OMG_CRO", price_precision=3, quantity_precision=2)
 OMG_USDT = Pair("OMG_USDT", price_precision=4, quantity_precision=4)
 ONT_BTC = Pair("ONT_BTC", price_precision=8, quantity_precision=2)
@@ -84,29 +96,38 @@ QTUM_CRO = Pair("QTUM_CRO", price_precision=3, quantity_precision=2)
 QTUM_USDT = Pair("QTUM_USDT", price_precision=4, quantity_precision=4)
 REN_CRO = Pair("REN_CRO", price_precision=4, quantity_precision=2)
 REN_USDT = Pair("REN_USDT", price_precision=5, quantity_precision=2)
-SKL_USDT = Pair("SKL_USDT", price_precision=6, quantity_precision=4)
+SAND_CRO = Pair("SAND_CRO", price_precision=4, quantity_precision=2)
+SAND_USDT = Pair("SAND_USDT", price_precision=5, quantity_precision=2)
+SKL_USDT = Pair("SKL_USDT", price_precision=5, quantity_precision=2)
+SNX_CRO = Pair("SNX_CRO", price_precision=2, quantity_precision=3)
+SNX_USDT = Pair("SNX_USDT", price_precision=3, quantity_precision=3)
+THETA_USDT = Pair("THETA_USDT", price_precision=4, quantity_precision=2)
+UMA_BTC = Pair("UMA_BTC", price_precision=7, quantity_precision=4)
+UMA_CRO = Pair("UMA_CRO", price_precision=2, quantity_precision=4)
+UMA_USDT = Pair("UMA_USDT", price_precision=3, quantity_precision=4)
 UNI_CRO = Pair("UNI_CRO", price_precision=3, quantity_precision=2)
 UNI_USDT = Pair("UNI_USDT", price_precision=4, quantity_precision=4)
 USDC_USDT = Pair("USDC_USDT", price_precision=4, quantity_precision=2)
-VET_BTC = Pair("VET_BTC", price_precision=8, quantity_precision=0)
+VET_BTC = Pair("VET_BTC", price_precision=10, quantity_precision=0)
 VET_CRO = Pair("VET_CRO", price_precision=4, quantity_precision=0)
 VET_USDT = Pair("VET_USDT", price_precision=6, quantity_precision=0)
-WBTC_BTC = Pair("WBTC_BTC", price_precision=4, quantity_precision=4)
+WBTC_BTC = Pair("WBTC_BTC", price_precision=4, quantity_precision=6)
 WBTC_USDT = Pair("WBTC_USDT", price_precision=2, quantity_precision=6)
-XLM_BTC = Pair("XLM_BTC", price_precision=8, quantity_precision=0)
+XLM_BTC = Pair("XLM_BTC", price_precision=9, quantity_precision=0)
 XLM_CRO = Pair("XLM_CRO", price_precision=3, quantity_precision=2)
 XLM_USDT = Pair("XLM_USDT", price_precision=5, quantity_precision=1)
-XRP_BTC = Pair("XRP_BTC", price_precision=8, quantity_precision=0)
-XRP_CRO = Pair("XRP_CRO", price_precision=2, quantity_precision=0)
+XRP_BTC = Pair("XRP_BTC", price_precision=9, quantity_precision=0)
+XRP_CRO = Pair("XRP_CRO", price_precision=3, quantity_precision=0)
 XRP_USDT = Pair("XRP_USDT", price_precision=5, quantity_precision=1)
-XTZ_BTC = Pair("XTZ_BTC", price_precision=7, quantity_precision=2)
+XTZ_BTC = Pair("XTZ_BTC", price_precision=8, quantity_precision=2)
 XTZ_CRO = Pair("XTZ_CRO", price_precision=3, quantity_precision=2)
 XTZ_USDT = Pair("XTZ_USDT", price_precision=4, quantity_precision=2)
-YFI_BTC = Pair("YFI_BTC", price_precision=4, quantity_precision=4)
-YFI_CRO = Pair("YFI_CRO", price_precision=2, quantity_precision=4)
+YFI_BTC = Pair("YFI_BTC", price_precision=4, quantity_precision=6)
+YFI_CRO = Pair("YFI_CRO", price_precision=2, quantity_precision=6)
 YFI_USDT = Pair("YFI_USDT", price_precision=2, quantity_precision=6)
 ZIL_CRO = Pair("ZIL_CRO", price_precision=4, quantity_precision=2)
 ZIL_USDT = Pair("ZIL_USDT", price_precision=5, quantity_precision=1)
+ZRX_USDT = Pair("ZRX_USDT", price_precision=4, quantity_precision=2)
 
 
 def all():
